==> django-bootstrap-icons-0.7.9.tar.gz: django-bootstrap-icons-0.7.9/CHANGELOG.md <==
# Change Log

<!-- GENERATOR_PLACEHOLDER -->

## 0.7.9

- Update default Bootstrap Icons CDN to version 1.8.2
- Update default Material Icons CDN to 6.6.96

## 0.7.8

- Fix default alingment of icons from -0.125em to rem 

## 0.7.7

- Update default bootstrap icons CDN to version 1.8.1

## 0.7.6

- Update default bootstrap icons CDN to version 1.8.0

## 0.7.5

### Changed
- Include sample app in repository
- Added basic tests
- Moved release information to CHANGELOG.md

### Fixed
- Replace blanks in cache file names with underscores

## 0.7.4

### Updated
- Update default bootstrap icons CDN to version 1.7.2

## 0.7.3

### Updated
- Update default bootstrap icons CDN to version 1.7.1

## 0.7.2

### Updated
- Update default bootstrap icons CDN to version 1.7.0, update default Material Icons CDN to 6.4.95

## 0.7.1

### Updated
- Update default bootstrap icons CDN to bugfix version 1.6.1

## 0.7.0

### Updated
- Update default bootstrap icons CDN to version 1.6.0

## 0.6.4 

### Changed
- Improve error handling for custom icons

## 0.6.3

### Changed
- Add a configuration option what to display if icons are not found.

## 0.6.2

### Changed
- Add icon cache to avoid multiple redering of same icon ([#5](https://github.com/christianwgd/django-bootstrap-icons/issues/5))

## 0.6.1

### Fixed
- Fix path building on windows ([#3](https://github.com/christianwgd/django-bootstrap-icons/issues/3))

## 0.6.0

### Updated
- Update default bootstrap icons CDN to version 1.5.0

## 0.5.5

### Changed
- Add support for Material Design Icons, no need to install as long as you don't want to use MDI.

## 0.5.4

### Fixed
- Fix some documentation issues, no need to install since it affects only documentation

## 0.5.3

### Changed
- Add css to specify vertical alignment of sgv icons

## 0.5.2

### Fixed
- Handle error if custom icon svg does not exist


## 0.5.1

### Fixed
- Fix incorrect template tag names in documentation ([#3494](https://github.com/cookiecutter/cookiecutter-django/pull/3494))

## 0.5.0

### Changed
- Refactor to use bootstrap svg icons from CDN

==> django-bootstrap-icons-0.8.1.tar.gz: django-bootstrap-icons-0.8.1/CHANGELOG.md <==
# Change Log

<!-- GENERATOR_PLACEHOLDER -->

## 0.8.1

### Fixed
- Vertical alignment couldn't be set by extra_classes

## 0.8.0

### Changed
- Update default Bootstrap Icons CDN to version 1.9.0
- Update default Material Icons CDN to 6.9.96

### Fixed
- Set alignment to default if no class is provided for bi and mdi icons

## 0.7.9

- Update default Bootstrap Icons CDN to version 1.8.2
- Update default Material Icons CDN to 6.6.96

## 0.7.8

- Fix default alingment of icons from -0.125em to rem 

## 0.7.7

- Update default bootstrap icons CDN to version 1.8.1

## 0.7.6

- Update default bootstrap icons CDN to version 1.8.0

## 0.7.5

### Changed
- Include sample app in repository
- Added basic tests
- Moved release information to CHANGELOG.md

### Fixed
- Replace blanks in cache file names with underscores

## 0.7.4

### Updated
- Update default bootstrap icons CDN to version 1.7.2

## 0.7.3

### Updated
- Update default bootstrap icons CDN to version 1.7.1

## 0.7.2

### Updated
- Update default bootstrap icons CDN to version 1.7.0, update default Material Icons CDN to 6.4.95

## 0.7.1

### Updated
- Update default bootstrap icons CDN to bugfix version 1.6.1

## 0.7.0

### Updated
- Update default bootstrap icons CDN to version 1.6.0

## 0.6.4 

### Changed
- Improve error handling for custom icons

## 0.6.3

### Changed
- Add a configuration option what to display if icons are not found.

## 0.6.2

### Changed
- Add icon cache to avoid multiple redering of same icon ([#5](https://github.com/christianwgd/django-bootstrap-icons/issues/5))

## 0.6.1

### Fixed
- Fix path building on windows ([#3](https://github.com/christianwgd/django-bootstrap-icons/issues/3))

## 0.6.0

### Updated
- Update default bootstrap icons CDN to version 1.5.0

## 0.5.5

### Changed
- Add support for Material Design Icons, no need to install as long as you don't want to use MDI.

## 0.5.4

### Fixed
- Fix some documentation issues, no need to install since it affects only documentation

## 0.5.3

### Changed
- Add css to specify vertical alignment of sgv icons

## 0.5.2

### Fixed
- Handle error if custom icon svg does not exist


## 0.5.1

### Fixed
- Fix incorrect template tag names in documentation ([#3494](https://github.com/cookiecutter/cookiecutter-django/pull/3494))

## 0.5.0

### Changed
- Refactor to use bootstrap svg icons from CDN
